@@ -11,11 +11,9 @@ module Test.Hspec.Discover {-# WARNING
 , module Prelude
 ) where
 
-import           Prelude hiding (mapM)
-
 import           Test.Hspec.Core.Spec
 import           Test.Hspec.Core.Runner
-import           Test.Hspec.Formatters
+import           Test.Hspec.Core.Formatters.V1
 
 class IsFormatter a where
   toFormatter :: a -> IO Formatter
